| medium_example_data | R Documentation |
A medium sized example dataset consisting of 111 observations in a (50m x 50m) square domain.
data("medium_example_data")
## medium_example_data
A data frame with 111 rows and 3 columns:
x coordinate
y coordinate
Size
...
The dataset was generated using the Snodgrass dataset available at https://data.ess-dive.lbl.gov/view/doi:10.15485/2476543.
The full code to generate this dataset is available in the package's data_raw directory.
Real example dataset. Code to generate it can be found in data_raw/medium_example_data.R.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.