vec_to_mat_dist: calculates euclidean distance between a vector and a matrix
Description
calculates euclidean distance between a vector and a matrix
Usage
vec_to_mat_dist(eval_u, x_col, y_col)
Value
a vector of distances between a vector and each row of a matrix.
Arguments
- eval_u
a vector of x and y coordinates.
- x_col
a vector of x coordinates.
- y_col
a vector of y coordinates.