Learn R Programming

ldmppr (version 1.1.2)

ldmppr_budgets: Create an optimization budget specification for estimate_process_parameters()

Description

ldmppr_budgets() defines per-stage optimization options (budgets) used by estimate_process_parameters for NLopt via nloptr.

Usage

ldmppr_budgets(
  global_options = NULL,
  local_budget_first_level = NULL,
  local_budget_refinement_levels = NULL
)

Value

an object of class "ldmppr_budgets".

Arguments

global_options

(optional) list of NLopt options used for the global stage (only relevant when strategy uses a global optimizer). Examples: list(maxeval = 2000, maxtime = 10).

local_budget_first_level

(optional) list of NLopt options used for the local stage at the first (coarsest) grid level.

local_budget_refinement_levels

(optional) list of NLopt options used for local refinement on subsequent (finer) grid levels in multi-resolution strategies. If NULL, the estimator will fall back to local_budget_first_level.

Details

The returned object is an S3 class. Use summary() and as.data.frame() methods to inspect.

See Also

ldmppr_grids-class for methods and details.

Examples

Run this code
b <- ldmppr_budgets(
  global_options = list(maxeval = 150),
  local_budget_first_level = list(maxeval = 300, xtol_rel = 1e-5),
  local_budget_refinement_levels = list(maxeval = 150, xtol_rel = 1e-5)
)
b

Run the code above in your browser using DataLab