| ldmppr_model_check | R Documentation |
Objects of class ldmppr_model_check are returned by check_model_fit.
They contain global envelope test results and curve sets for multiple summary
functions/statistics.
## S3 method for class 'ldmppr_model_check'
print(x, ...)
## S3 method for class 'ldmppr_model_check'
summary(object, ...)
## S3 method for class 'summary.ldmppr_model_check'
print(x, ...)
## S3 method for class 'ldmppr_model_check'
plot(x, which = c("combined", "L", "F", "G", "J", "E", "V"), ...)
x |
an object of class |
... |
additional arguments passed to the underlying |
object |
an object of class |
which |
which envelope to plot. |
An ldmppr_model_check is a list with components such as:
combined_env: a global envelope test object (typically from **GET**)
envs: named list of envelope test objects (e.g., L, F, G, J, E, V)
curve_sets: named list of curve set objects
settings: list of settings used when generating envelopes (e.g., n_sim, thinning)
print()prints a brief summary of the diagnostic object.
summary()returns a summary.ldmppr_model_check object.
plot()plots the combined envelope or a selected statistic envelope.
print(ldmppr_model_check): Print a brief summary of the diagnostic results.
summary(ldmppr_model_check): Summarize p-values from the combined and individual envelopes.
plot(ldmppr_model_check): Plot the combined envelope or a selected statistic.
print(summary.ldmppr_model_check): Print a summary produced by summary.ldmppr_model_check.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.