| ldmppr_sim | R Documentation |
ldmppr_sim objects are returned by simulate_mpp. They contain the simulated
realization, an associated marked point pattern object, and metadata used to
reproduce or inspect the simulation.
## S3 method for class 'ldmppr_sim'
print(x, ...)
## S3 method for class 'ldmppr_sim'
summary(object, ...)
## S3 method for class 'summary.ldmppr_sim'
print(x, ...)
## S3 method for class 'ldmppr_sim'
as.data.frame(x, ...)
## S3 method for class 'ldmppr_sim'
nobs(object, ...)
## S3 method for class 'ldmppr_sim'
plot(x, pattern_type = "simulated", ...)
mpp.ldmppr_sim(x, ...)
x |
a |
... |
additional arguments (not used). |
object |
a |
pattern_type |
type of pattern to plot |
An ldmppr_sim is a list with at least:
process: process name (e.g. "self_correcting")
mpp: a marked point pattern object
realization: data.frame with columns time, x, y, marks
params, bounds, and other metadata
For methods:
print()prints a summary of the simulation.
summary()returns a summary.ldmppr_sim object.
plot()returns a ggplot visualization of the marked point pattern.
as.data.frame()returns the simulated realization as a data.frame.
nobs()returns the number of points in the realization.
mpp()returns the marked point pattern object.
print(ldmppr_sim): Print a brief summary of the simulation.
summary(ldmppr_sim): Summarize a simulated realization.
as.data.frame(ldmppr_sim): Coerce to a data.frame of the simulated realization.
nobs(ldmppr_sim): Number of simulated points.
plot(ldmppr_sim): Plot the simulated marked point pattern.
print(summary.ldmppr_sim): Print a summary produced by summary.ldmppr_sim.
mpp.ldmppr_sim(): Extract the underlying marked point pattern object.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.