ldmppr_sim objects are returned by simulate_mpp. They contain the simulated
realization, an associated marked point pattern object, and metadata used to
reproduce or inspect the simulation.
# S3 method for ldmppr_sim
print(x, ...)# S3 method for ldmppr_sim
summary(object, ...)
# S3 method for summary.ldmppr_sim
print(x, ...)
# S3 method for ldmppr_sim
as.data.frame(x, ...)
# S3 method for ldmppr_sim
nobs(object, ...)
# S3 method for ldmppr_sim
plot(x, pattern_type = "simulated", ...)
mpp.ldmppr_sim(x, ...)
For methods:
print()prints a summary of the simulation.
summary()returns a summary.ldmppr_sim object.
plot()returns a ggplot visualization of the marked point pattern.
as.data.frame()returns the simulated realization as a data.frame.
nobs()returns the number of points in the realization.
mpp()returns the marked point pattern object.
a ldmppr_sim object.
additional arguments (not used).
a ldmppr_sim object.
type of pattern to plot "simulated" (default).
print(ldmppr_sim): Print a brief summary of the simulation.
summary(ldmppr_sim): Summarize a simulated realization.
as.data.frame(ldmppr_sim): Coerce to a data.frame of the simulated realization.
nobs(ldmppr_sim): Number of simulated points.
plot(ldmppr_sim): Plot the simulated marked point pattern.
print(summary.ldmppr_sim): Print a summary produced by summary.ldmppr_sim.
mpp.ldmppr_sim(): Extract the underlying marked point pattern object.
An ldmppr_sim is a list with at least:
process: process name (e.g. "self_correcting")
mpp: a marked point pattern object
realization: data.frame with columns time, x, y, marks
params, bounds, and other metadata