powered by
Gentle decay (power-law) mapping function from sizes to arrival times
power_law_mapping(sizes, delta)
vector of arrival times.
vector of sizes to be mapped to arrival times.
numeric value (greater than 0) for the exponent in the mapping function.
# Generate a vector of sizes sizes <- runif(100, 0, 100) # Map the sizes to arrival times using a power-law mapping with delta = .5 power_law_mapping(sizes, .5)
Run the code above in your browser using DataLab