Prefer using the S3 method predict() on an ldmppr_mark_model:
predict(mark_model, sim_realization = ..., xy_bounds = ...).
This wrapper is retained for backward compatibility and is deprecated.
predict_marks(
sim_realization,
raster_list = NULL,
scaled_rasters = FALSE,
mark_model = NULL,
xy_bounds = NULL,
include_comp_inds = FALSE,
competition_radius = 15,
edge_correction = "none",
seed = NULL
)a vector of predicted mark values.
a data.frame containing a thinned or unthinned realization from
simulate_mpp (or simulate_sc). Must contain x, y, and time.
list of raster objects used for mark prediction.
TRUE or FALSE indicating whether rasters are already scaled.
a mark model object. May be an ldmppr_mark_model, model_fit, or workflow.
vector of domain bounds as c(a_x, b_x, a_y, b_y).
TRUE or FALSE indicating whether to generate and use competition indices as covariates.
positive numeric distance used when include_comp_inds = TRUE.
type of edge correction to apply ("none" or "toroidal").
optional nonnegative integer seed for reproducibility.